@@ -119,6 +119,15 @@ class Locale:
                 'xkblayout':'us,it',
                 'language':'it',
         },
+    'nl_BE' : {
+                'name':__('Nederland'),
+                'locale':'nl_BE.UTF-8',
+                'keymap':'nl',
+                'dumpkeys_charset':'',
+                'consolefont':'lat9w-16',
+                'xkblayout':'us,nl',
+                'language':'nl',
+        },
     'nn_NO' : {
                 'name':__('Norwegian'),
                 'locale':'nn_NO.UTF-8',
@@ -321,7 +330,7 @@ class VariableOsLang(ReadonlyVariable,Locale):
 
     def get(self):
         return list(sorted(list(set(self.getLangs()) &
-            set(["en_US","de_DE","es_ES","fr_FR","it_IT","pl_PL","pt_BR",
+            set(["en_US", "nl_BE", "de_DE","es_ES","fr_FR","it_IT","pl_PL","pt_BR",
                 "uk_UA","bg_BG","ru_RU","ro_RO","pt_PT"]))))
 
     def humanReadable(self):
